# enable_gtkdoc: Toggle if gtkdoc stuff should be rebuilt
#	0 = no
#	1 = yes
%define enable_gtkdoc	1

# This package has static probes which do not work with LTO
# Disable LTO
%define _lto_cflags %{nil}

# Note that this is NOT a relocatable package
%define api_version	2.0
%define lib_major	0
%define lib_name	%mklibname %{name}_ %{lib_major}
%define libgio_name	%mklibname gio%{api_version}_ %{lib_major}
%define develname	%mklibname -d %name
%define staticname	%mklibname -d -s %name

%define url_ver		%(echo %{version}|cut -d. -f1,2)

Summary:	A library of handy utility functions
Name:		glib%{api_version}
Version:	2.66.7
Release:	%mkrel 1
License:	LGPLv2+
Group:		System/Libraries
URL:		http://www.gtk.org
Source0:	https://download.gnome.org/sources/glib/%{url_ver}/glib-%{version}.tar.xz
Source1:	glib20.sh
Source2:	glib20.csh
# (tmb) disable deprecated schema warnings on mga3 like we did for mga2
Patch0:		glib-silence-deprecated-paths.patch
# Disable statx as it makes Firefox and Chromium crash (mga#27234),
# and upstream doesn't care:
# https://gitlab.gnome.org/GNOME/glib/-/issues/2198
Patch2:         glib-2.65.2-disable-statx.patch
Source3:	glib-2.57.2-guard-against-reading-past-the-end-of-a-timezone-file.patch
# Avoid requiring a too new gtk-doc version for building glib
Patch4:		gtk-doc-1-32.patch
# https://gitlab.gnome.org/GNOME/glib/-/commit/e4af46fc09b99c606a5c2a0af511e0352ff1b4be
# https://gitlab.gnome.org/GNOME/glib/-/commit/0d50c6bbe6be4ccc145452e8c8d2a8f853073870
Requires:	common-licenses
Requires:	shared-mime-info >= 0.70
BuildRequires:	systemtap
BuildRequires:	pkgconfig(libpcre) >= 8.11
BuildRequires:	pkgconfig(mount)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(dbus-1) >= 1.2.14
BuildRequires:	gettext
BuildRequires:	libtool
BuildRequires:	locales-en
BuildRequires:	pkgconfig(libffi) >= 3.0.0
BuildRequires:	xsltproc
BuildRequires:	docbook-dtds
BuildRequires:	docbook-xsl
BuildRequires:	docbook-style-xsl
BuildRequires:	libxml2-utils
BuildRequires:	meson
# for sys/sdt.h
BuildRequires:	systemtap-sdt-devel
# ovitters adds elf support to gresource binary, needed to determine
#          gnome-shell requires
BuildRequires:	elfutils-devel
%if %enable_gtkdoc
BuildRequires:	gtk-doc >= 0.10
%endif
BuildRequires:	pkgconfig(python3)

%description
Glib is a handy library of utility functions. This C
library is designed to solve some portability problems
and provide other useful functionality which most
programs require.

Glib is used by GDK, GTK+ and many applications.

%package common
Summary:	data files used by glib
Group:		System/Libraries

%description common
Glib is a handy library of utility functions. This C
library is designed to solve some portability problems
and provide other useful functionality which most
programs require.

This package contains data used by glib library.

%package -n %{lib_name}
Summary:	%{summary}
Group:		%{group}
Provides:	glib2 = %{version}-%{release}
Provides:	libglib2 = %{version}-%{release}
Provides:	lib%{name} = %{version}-%{release}

%description -n %{lib_name}
Glib is a handy library of utility functions. This C
library is designed to solve some portability problems
and provide other useful functionality which most
programs require.

Glib is used by GDK, GTK+ and many applications.
You should install Glib because many of your applications
will depend on this library.

This package contains the library needed to run programs dynamically
linked with the glib.

%package -n %{libgio_name}
Summary:	GIO is the input, output and streaming API of glib
Group:		%{group}
Requires:	%{lib_name} = %{version}
Requires:	shared-mime-info
Recommends:	%{mklibname glib-networking-gnutls}

%description -n %{libgio_name}
GIO is the input, output and streaming API of glib. It on the one hand
provides a set of various streaming classes to access data from different
sources in a convenient way and on the other hand it provides a high level
file system abstraction to access file and directories not only local but also
on the network. For the latter you need to install gvfs.

%package -n %develname
Summary:	Static libraries and header files of %{name}
Group:		Development/C
Provides:	glib2-devel = %{version}-%{release}
Provides:	libglib2-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Requires:	%{lib_name} = %{version}
Requires:	%{libgio_name} = %{version}
Requires:	%{name}-common = %{version}
Requires:	glib-gettextize >= %{version}

%description -n %develname
Header files for the support library for the GIMP's X libraries, which are
available as public libraries. GLIB includes generally useful data structures.

%package -n %staticname
Summary:	Static libraries and header files of %{name}
Group:		Development/C
Requires:	%develname = %{version}-%{release}
Provides:	glib2-static-devel = %{version}-%{release}
Provides:	libglib2-static-devel = %{version}-%{release}
Provides:	lib%{name}-static-devel = %{version}-%{release}

%description -n %staticname
Static libraries and files for the support library for the GIMP's X libraries,
which are available as public libraries. GLIB includes generally useful data
structures.

%package -n glib-gettextize
Summary:	Gettextize replacement
Group:		Development/Other

%description -n glib-gettextize
%{name} package is designed to replace gettextize completely.
Various gettext related files are modified in glib and gtk+ to
allow better and more flexible i18n; however gettextize overwrites
them with its own copy of files, thus nullifying the changes.
If this replacement of gettextize is run instead, then all gnome
packages can potentially benefict from the changes.

%package tests
Summary: Tests for the glib2 package
Requires: %{lib_name}%{?_isa} = %{version}-%{release}

%description tests
The glib2-tests package contains tests that can be used to verify
the functionality of the installed glib2 package.

%prep
%autosetup -n glib-%{version} -p1

%build
%meson \
	-Dselinux=disabled \
	--default-library=both \
	-Dman=true \
	-Ddtrace=true \
	-Dsystemtap=true \
	-Dinstalled_tests=true \
%if !%enable_gtkdoc
	-Dgtk_doc=false
%else
	-Dgtk_doc=true
%endif
%meson_build

%check
#gw http://bugzilla.gnome.org/show_bug.cgi?id=440544
#make check

%install
%meson_install

mkdir -p %{buildroot}%{_sysconfdir}/profile.d
install -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/profile.d/50glib20.sh
install -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/profile.d/50glib20.csh

%find_lang glib20

mv %{buildroot}%{_bindir}/gio-querymodules %{buildroot}%{_bindir}/gio-querymodules-%{__isa_bits}

#ghost files
mkdir -p %buildroot%_libdir/gio/modules
mkdir -p %buildroot%_datadir/glib-2.0/schemas
touch %buildroot%_libdir/gio/modules/giomodule.cache \
      %buildroot%_datadir/glib-2.0/schemas/gschemas.compiled

# don't ship .a files for gio modules
rm -f %buildroot%_libdir/gio/modules/lib*a

# we don't want these
find %{buildroot} -name "*.la" -delete
rm -f %{buildroot}%{_datadir}/glib-2.0/gdb/*.{pyc,pyo}
rm -f %{buildroot}%{_datadir}/glib-2.0/codegen/*.{pyc,pyo}

# automatic gschema compilation on rpm installs/removals
%transfiletriggerpostun -n %{name}-common --  %_datadir/glib-2.0/schemas/
if [ -x /usr/bin/glib-compile-schemas ]; then
	/usr/bin/glib-compile-schemas --allow-any-name %_datadir/glib-2.0/schemas/
fi

%transfiletriggerin -n %{name}-common --  %_datadir/glib-2.0/schemas/
if [ -x /usr/bin/glib-compile-schemas ]; then
	/usr/bin/glib-compile-schemas --allow-any-name %_datadir/glib-2.0/schemas/
fi

# automatic update of gio module cache
%transfiletriggerpostun -n %{libgio_name} -- %{_libdir}/gio/modules/
if [ -x %{_bindir}/gio-querymodules-%{__isa_bits} ]; then
  %{_bindir}/gio-querymodules-%{__isa_bits} %{_libdir}/gio/modules
fi

%transfiletriggerin -n %{libgio_name} -- %{_libdir}/gio/modules/
if [ -x %{_bindir}/gio-querymodules-%{__isa_bits} ]; then
  %{_bindir}/gio-querymodules-%{__isa_bits} %{_libdir}/gio/modules
fi

%files common -f glib20.lang
%doc README.md
%config(noreplace) %{_sysconfdir}/profile.d/*
%_datadir/bash-completion/completions/gapplication
%_datadir/bash-completion/completions/gdbus
%_datadir/bash-completion/completions/gio
%_datadir/bash-completion/completions/gsettings
%_datadir/bash-completion/completions/gresource
%{_bindir}/gapplication
%{_bindir}/gdbus
%{_bindir}/gio
%{_bindir}/glib-compile-schemas
%{_bindir}/glib-compile-resources
%{_bindir}/gresource
%{_bindir}/gsettings
%{_mandir}/man1/gio-querymodules.1*
%_mandir/man1/glib-compile-schemas.1*
%_mandir/man1/glib-compile-resources.1*
%_mandir/man1/gsettings.1*
%{_mandir}/man1/gapplication.1*
%{_mandir}/man1/gdbus.1*
%{_mandir}/man1/gio.1*
%{_mandir}/man1/gresource.1*
%dir %_datadir/glib-2.0/
%dir %_datadir/glib-2.0/schemas/
%_datadir/glib-2.0/schemas/gschema.dtd
%ghost %_datadir/glib-2.0/schemas/gschemas.compiled
%_datadir/gettext/its/
%{_datadir}/glib-2.0/valgrind/*.*

%files -n %{lib_name}
%doc README.md
%{_libdir}/libglib-%{api_version}.so.%{lib_major}{,.*}
%{_libdir}/libgmodule-%{api_version}.so.%{lib_major}{,.*}
%{_libdir}/libgthread-%{api_version}.so.%{lib_major}{,.*}
%{_libdir}/libgobject-%{api_version}.so.%{lib_major}{,.*}

%files -n %{libgio_name}
%_bindir/gio-querymodules-%{__isa_bits}
%{_libdir}/libgio-%{api_version}.so.%{lib_major}{,.*}
%dir %_libdir/gio/
%dir %_libdir/gio/modules/
%ghost %_libdir/gio/modules/giomodule.cache

%files -n %develname
%doc AUTHORS NEWS
%doc %{_datadir}/gtk-doc/html/*
%{_libdir}/lib*.so
%{_libdir}/glib-%{api_version}
%{_datadir}/glib-%{api_version}/codegen
%{_libdir}/pkgconfig/*
%{_includedir}/*
%{_mandir}/man1/glib-genmarshal.1*
%{_mandir}/man1/glib-mkenums.1*
%{_mandir}/man1/gobject-query.1*
%{_mandir}/man1/gtester-report.1*
%{_mandir}/man1/gtester.1*
%{_mandir}/man1/gdbus-codegen.1*
%{_datadir}/aclocal/glib-%{api_version}.m4
%{_datadir}/aclocal/gsettings.m4
%{_bindir}/glib-genmarshal
%{_bindir}/glib-mkenums
%{_bindir}/gobject-query
%{_bindir}/gtester*
%{_bindir}/gdbus-codegen
%{_datadir}/gdb/auto-load%{_libdir}/lib*-gdb.py*
%{_datadir}/glib-%{api_version}/gdb
%{_datadir}/systemtap/
%{_datadir}/gdb/auto-load%{_libdir}/__pycache__/*


%files -n glib-gettextize
%{_bindir}/glib-gettextize
%_mandir/man1/glib-gettextize.1*
%{_datadir}/aclocal/glib-gettext.m4
%{_datadir}/glib-%{api_version}/gettext

%files -n %staticname
%{_libdir}/lib*.a

%files tests
%{_libexecdir}/installed-tests
%{_datadir}/installed-tests


%changelog
* Sat Feb 27 2021 tmb <tmb> 2.66.7-1.mga8
+ Revision: 1693007
- update to 2.66.7 (mga#28392)

* Wed Feb 03 2021 tmb <tmb> 2.66.4-3.mga8
+ Revision: 1674735
- spawn: Don't set a search path if we don't want to search PATH

* Wed Feb 03 2021 tmb <tmb> 2.66.4-2.mga8
+ Revision: 1674731
- gthread: Destroy value after replacing it in g_private_replace()

* Thu Dec 17 2020 ovitters <ovitters> 2.66.4-1.mga8
+ Revision: 1659805
- new version 2.66.4

* Mon Nov 16 2020 ovitters <ovitters> 2.66.3-1.mga8
+ Revision: 1646627
- new version 2.66.3

* Mon Oct 19 2020 ovitters <ovitters> 2.66.2-1.mga8
+ Revision: 1637131
- new version 2.66.2

* Thu Oct 01 2020 ovitters <ovitters> 2.66.1-1.mga8
+ Revision: 1631468
- new version 2.66.1

* Fri Sep 11 2020 tv <tv> 2.66.0-1.mga8
+ Revision: 1624735
- 2.66.0

* Sun Sep 06 2020 tv <tv> 2.65.3-1.mga8
+ Revision: 1622938
- 2.65.2

* Thu Sep 03 2020 akien <akien> 2.65.2-2.mga8
+ Revision: 1621247
- Disable statx support which violates Firefox and Chromium sandboxing (mga#27234)

* Sun Aug 30 2020 tv <tv> 2.65.2-1.mga8
+ Revision: 1619697
- 2.65.2
- Backport fix for GGO #2189 (error accessing some filesystems)
- disable glib-2.57.2-guard-against-reading-past-the-end-of-a-timezone-file.patch
  (code has changed too much)

* Fri Jul 31 2020 wally <wally> 2.65.0-2.mga8
+ Revision: 1609965
- drop upstream merged xfce4-terminal and mate-terminal support patch

* Thu Jul 09 2020 ovitters <ovitters> 2.65.0-1.mga8
+ Revision: 1603484
- new version 2.65.0

* Thu Jul 02 2020 ovitters <ovitters> 2.64.4-1.mga8
+ Revision: 1601379
- new version 2.64.4

* Tue Jun 16 2020 ovitters <ovitters> 2.64.3-2.mga8
+ Revision: 1593476
- rebuild for new ffi

* Wed May 20 2020 ovitters <ovitters> 2.64.3-1.mga8
+ Revision: 1586395
- new version 2.64.3

* Thu Apr 09 2020 ovitters <ovitters> 2.64.2-1.mga8
+ Revision: 1565835
- new version 2.64.2

* Wed Mar 11 2020 ovitters <ovitters> 2.64.1-1.mga8
+ Revision: 1555627
- re-enable installed tests
- new version 2.64.1

* Sat Feb 29 2020 tv <tv> 2.64.0-1.mga8
+ Revision: 1552389
- 2.64.0

* Mon Feb 24 2020 ovitters <ovitters> 2.63.6-1.mga8
+ Revision: 1550144
- new version 2.63.6
- dropped merged patch CVE-2020-6750.patch

* Thu Feb 20 2020 daviddavid <daviddavid> 2.63.5-3.mga8
+ Revision: 1547494
- add patch to fix CVE-2020-6750 (mga#26230)

* Tue Feb 18 2020 umeabot <umeabot> 2.63.5-2.mga8
+ Revision: 1541108
- Mageia 8 Mass Rebuild

* Mon Feb 17 2020 tv <tv> 2.63.5-1.mga8
+ Revision: 1537180
- add tests subpkg
- BR systemtap-sdt-devel
+ ovitters <ovitters>
- new version 2.63.5

* Thu Dec 19 2019 ovitters <ovitters> 2.62.4-1.mga8
+ Revision: 1469001
- new version 2.62.4

* Wed Nov 20 2019 daviddavid <daviddavid> 2.62.3-1.mga8
+ Revision: 1461870
- new version 2.62.3
- remove merged upstream previous patch

* Sat Nov 16 2019 daviddavid <daviddavid> 2.62.2-2.mga8
+ Revision: 1461122
- add upstream patch to avoid race condition authenticating GDBusServer
  with libdbus client (glib#1831) (mga#25525)
  * this issue come from a regression introduced since the original CVE-2019-14822

* Mon Oct 21 2019 ovitters <ovitters> 2.62.2-1.mga8
+ Revision: 1455059
- new version 2.62.2
+ tv <tv>
- remove no more needed requires exclude on bin/python3
- package README.md instead of useless README

* Fri Oct 04 2019 ovitters <ovitters> 2.62.1-1.mga8
+ Revision: 1449278
- new version 2.62.1

* Thu Sep 05 2019 ovitters <ovitters> 2.62.0-1.mga8
+ Revision: 1437652
- new version 2.62.0

* Mon Sep 02 2019 ovitters <ovitters> 2.61.3-1.mga8
+ Revision: 1436418
- new version 2.61.3

* Thu Aug 01 2019 ovitters <ovitters> 2.61.2-1.mga8
+ Revision: 1426828
- new version 2.61.2

* Wed Jul 24 2019 ovitters <ovitters> 2.60.6-1.mga8
+ Revision: 1423720
- new version 2.60.6

* Tue Jul 09 2019 ovitters <ovitters> 2.60.5-1.mga8
+ Revision: 1419722
- new version 2.60.5

* Tue Jul 02 2019 ovitters <ovitters> 2.60.4-1.mga8
+ Revision: 1417611
- new version 2.60.4

* Wed May 08 2019 tmb <tmb> 2.60.2-1.mga7
+ Revision: 1396775
- update to 2.60.2

* Wed Apr 17 2019 umeabot <umeabot> 2.60.1-2.mga7
+ Revision: 1392258
- Rebuild with meson 0.50.1

* Mon Apr 15 2019 ovitters <ovitters> 2.60.1-1.mga7
+ Revision: 1390741
- new version 2.60.1

* Thu Mar 07 2019 ovitters <ovitters> 2.60.0-1.mga7
+ Revision: 1372412
- switch to meson
- new version 2.60.0

* Thu Feb 07 2019 wally <wally> 2.58.3-2.mga7
+ Revision: 1364039
- add also mate-terminal to supported terminals in GIO

* Mon Jan 21 2019 ovitters <ovitters> 2.58.3-1.mga7
+ Revision: 1358680
- new version 2.58.3

* Sat Dec 29 2018 wally <wally> 2.58.2-2.mga7
+ Revision: 1346584
- move gio module cache update transfiletriggers to correct pkg and make sure binary exists before running it
- drop unneeded post script as transfiletriggers does the same
- drop unneeded post requires from gio lib
- drop old conflicts and obsoletes

* Tue Dec 18 2018 ovitters <ovitters> 2.58.2-1.mga7
+ Revision: 1342559
- new version 2.58.2

* Fri Sep 21 2018 ovitters <ovitters> 2.58.1-1.mga7
+ Revision: 1294687
- new version 2.58.1

* Thu Aug 30 2018 ovitters <ovitters> 2.58.0-1.mga7
+ Revision: 1255769
- new version 2.58.0

* Thu Aug 23 2018 ovitters <ovitters> 2.57.3-1.mga7
+ Revision: 1253568
- new version 2.57.3

* Wed Aug 08 2018 guillomovitch <guillomovitch> 2.57.2-1.mga7
+ Revision: 1250071
- new version 2.57.2

* Sat Apr 07 2018 ovitters <ovitters> 2.56.1-1.mga7
+ Revision: 1215912
- new version 2.56.1
+ kekepower <kekepower>
- Use new make macros

* Mon Mar 12 2018 ovitters <ovitters> 2.56.0-1.mga7
+ Revision: 1208707
- new version 2.56.0

* Wed Feb 07 2018 ovitters <ovitters> 2.55.2-1.mga7
+ Revision: 1199620
- new version 2.55.2

* Mon Jan 08 2018 ovitters <ovitters> 2.54.3-1.mga7
+ Revision: 1191766
- new version 2.54.3

* Sat Oct 28 2017 ovitters <ovitters> 2.54.2-1.mga7
+ Revision: 1174332
- new version 2.54.2

* Thu Oct 12 2017 wally <wally> 2.54.1-3.mga7
+ Revision: 1171407
- add patch to really fix gdbus-codegen failure when called as /bin/gdbus-codegen

* Thu Oct 12 2017 wally <wally> 2.54.1-2.mga7
+ Revision: 1171331
- add patch from upstream to fix gdbus-codegen failure when called as /bin/gdbus-codegen (bgo#786785)

* Mon Oct 02 2017 ovitters <ovitters> 2.54.1-1.mga7
+ Revision: 1162779
- new version 2.54.1

* Fri Sep 22 2017 tv <tv> 2.54.0-4.mga7
+ Revision: 1157039
- devel pkg: avoid file deps on python

* Fri Sep 22 2017 tv <tv> 2.54.0-3.mga7
+ Revision: 1157030
- build with systemtap support
- switch to python3

* Tue Sep 12 2017 cjw <cjw> 2.54.0-2.mga7
+ Revision: 1153311
- have libgio depend on shared-mime-info to fix gdk-pixbuf-pixdata

* Mon Sep 11 2017 ovitters <ovitters> 2.54.0-1.mga7
+ Revision: 1152643
- new version 2.54.0

* Mon Sep 04 2017 ovitters <ovitters> 2.53.7-1.mga7
+ Revision: 1151155
- new version 2.53.7

* Mon Aug 21 2017 ovitters <ovitters> 2.53.6-1.mga7
+ Revision: 1142555
- new version 2.53.6

* Mon Jun 26 2017 ovitters <ovitters> 2.52.3-1.mga6
+ Revision: 1108523
- new version 2.52.3
- dropped merged patch 0001-gmain-only-signal-GWakeup-right-before-or-during-a-b.patch

* Fri May 19 2017 tv <tv> 2.52.2-2.mga6
+ Revision: 1103218
- Backport a gmain GWakeup patch to fix timedatex high CPU usage (mga#20881)

* Mon May 08 2017 ovitters <ovitters> 2.52.2-1.mga6
+ Revision: 1099672
- new version 2.52.2

* Sat Apr 08 2017 ovitters <ovitters> 2.52.1-1.mga6
+ Revision: 1096100
- new version 2.52.1

* Tue Mar 21 2017 ovitters <ovitters> 2.52.0-1.mga6
+ Revision: 1093962
- new version 2.52.0

* Mon Feb 13 2017 ovitters <ovitters> 2.50.3-1.mga6
+ Revision: 1085974
- new version 2.50.3

* Mon Nov 07 2016 ovitters <ovitters> 2.50.2-1.mga6
+ Revision: 1065635
- new version 2.50.2

* Mon Oct 10 2016 ovitters <ovitters> 2.50.1-1.mga6
+ Revision: 1060035
- new version 2.50.1

* Tue Sep 20 2016 tv <tv> 2.50.0-1.mga6
+ Revision: 1054600
- BR pkgconfig(mount)
+ ovitters <ovitters>
- new version 2.50.0

* Sun Sep 18 2016 ovitters <ovitters> 2.49.7-1.mga6
+ Revision: 1053771
- new version 2.49.7

* Mon Aug 22 2016 ovitters <ovitters> 2.48.2-1.mga6
+ Revision: 1047876
- new version 2.48.2
+ tv <tv>
- also recompile schemas & update gio modules on removal

* Tue May 10 2016 ovitters <ovitters> 2.48.1-1.mga6
+ Revision: 1011991
- new version 2.48.1
- dropped merged patch 5

* Wed Apr 27 2016 tv <tv> 2.48.0-3.mga6
+ Revision: 1006718
- patch 4: fix firefox crash (bgo#7762994)
- new release

* Tue Mar 22 2016 ovitters <ovitters> 2.48.0-2.mga6
+ Revision: 994199
- fix multilib conflicts

* Tue Mar 22 2016 ovitters <ovitters> 2.48.0-1.mga6
+ Revision: 994081
- new version 2.48.0

* Wed Mar 16 2016 ovitters <ovitters> 2.47.92-1.mga6
+ Revision: 991592
- new version 2.47.92

* Tue Feb 16 2016 ovitters <ovitters> 2.47.6-1.mga6
+ Revision: 962145
- new version 2.47.6

* Mon Feb 15 2016 tv <tv> 2.47.5-1.mga6
+ Revision: 960753
- adjust file list
+ ovitters <ovitters>
- new version 2.47.5

* Thu Jan 14 2016 ovitters <ovitters> 2.47.4-2.mga6
+ Revision: 923084
- only recommend the gio gnutls module

* Wed Dec 16 2015 ovitters <ovitters> 2.47.4-1.mga6
+ Revision: 911052
- new version 2.47.4
- dropped merged patch 5

* Tue Dec 15 2015 ovitters <ovitters> 2.47.3-2.mga6
+ Revision: 910781
- add upstream patch for gobject introspection compilation

* Wed Nov 25 2015 ovitters <ovitters> 2.47.3-1.mga6
+ Revision: 906009
- new version 2.47.3

* Tue Nov 24 2015 ovitters <ovitters> 2.47.2-1.mga6
+ Revision: 905801
- new version 2.47.2

* Mon Nov 23 2015 ovitters <ovitters> 2.47.1-1.mga6
+ Revision: 904992
- new version 2.47.1

* Fri Nov 06 2015 ovitters <ovitters> 2.46.2-1.mga6
+ Revision: 898306
- new version 2.46.2

* Wed Oct 14 2015 ovitters <ovitters> 2.46.1-1.mga6
+ Revision: 891193
- new version 2.46.1

* Wed Sep 23 2015 fwang <fwang> 2.46.0-1.mga6
+ Revision: 882327
- 2.46.0

* Tue Sep 22 2015 wally <wally> 2.45.8-4.mga6
+ Revision: 882233
- drop verbosity from glib schemas filetrigger

* Tue Sep 22 2015 wally <wally> 2.45.8-3.mga6
+ Revision: 882223
- add %%transfiletriggerin scripts to a correct pkg

* Tue Sep 22 2015 wally <wally> 2.45.8-2.mga6
+ Revision: 882218
- temporarily add verbose output to glib schemas filetrigger to see if it's working

* Mon Sep 14 2015 ovitters <ovitters> 2.45.8-1.mga6
+ Revision: 879321
- new version 2.45.8

* Sat Sep 05 2015 tv <tv> 2.45.7-2.mga6
+ Revision: 873132
- switch to new upstream file trigger syntax

* Tue Sep 01 2015 ovitters <ovitters> 2.45.7-1.mga6
+ Revision: 871989
- new version 2.45.7

* Fri Aug 21 2015 tmb <tmb> 2.45.6-2.mga6
+ Revision: 867587
- rebuild for new gcc

* Wed Aug 19 2015 ovitters <ovitters> 2.45.6-1.mga6
+ Revision: 866025
- new version 2.45.6

* Wed Aug 19 2015 ovitters <ovitters> 2.45.5-1.mga6
+ Revision: 866016
- new version 2.45.5

* Tue Jul 21 2015 ovitters <ovitters> 2.45.4-1.mga6
+ Revision: 855843
- new version 2.45.4

* Tue Jun 23 2015 ovitters <ovitters> 2.45.3-1.mga6
+ Revision: 840550
- new version 2.45.3

* Sat Jun 20 2015 ovitters <ovitters> 2.45.2-1.mga6
+ Revision: 836816
- new version 2.45.2
- add recommends on libglib-networking (mga#15971)

* Fri May 08 2015 tmb <tmb> 2.42.1-2.mga5
+ Revision: 821490
- gio: Prevent hang when finalizing GThreadedSocketService
- gfile: make_directory_with_parents race condition
- gfile: Use g_error_matches

* Tue Nov 11 2014 ovitters <ovitters> 2.42.1-1.mga5
+ Revision: 796321
- new version 2.42.1

* Wed Oct 15 2014 umeabot <umeabot> 2.42.0-2.mga5
+ Revision: 747825
- Second Mageia 5 Mass Rebuild

* Mon Sep 22 2014 ovitters <ovitters> 2.42.0-1.mga5
+ Revision: 719199
- new version 2.42.0

* Tue Sep 16 2014 umeabot <umeabot> 2.41.5-3.mga5
+ Revision: 686608
- Rebuild to fix library dependencies
- Mageia 5 Mass Rebuild
+ tv <tv>
- use %%global for req/prov exclude

* Tue Sep 16 2014 ovitters <ovitters> 2.41.5-1.mga5
+ Revision: 676963
- new version 2.41.5
+ tv <tv>
- autoconvert to new prov/req excludes

* Tue Sep 02 2014 ovitters <ovitters> 2.41.4-1.mga5
+ Revision: 671052
- new version 2.41.4

* Sat Aug 16 2014 ovitters <ovitters> 2.41.3-1.mga5
+ Revision: 663950
- new version 2.41.3

* Sun Jul 20 2014 colin <colin> 2.41.2-1.mga5
+ Revision: 654720
- New version 2.41.2
- Rediff truncated timezone file guard patch

* Tue Jun 24 2014 ovitters <ovitters> 2.41.1-2.mga5
+ Revision: 639321
- update summary and description

* Tue Jun 24 2014 ovitters <ovitters> 2.41.1-1.mga5
+ Revision: 639179
- new version 2.41.1

* Sat Jun 07 2014 ovitters <ovitters> 2.41.0-1.mga5
+ Revision: 634328
- new version 2.41.0

* Sat May 24 2014 blino <blino> 2.40.0-2.mga5
+ Revision: 625252
- add patches from upstream bgo#730332 to fix wrong timezone parsing (mga#13407)

* Mon Mar 24 2014 ovitters <ovitters> 2.40.0-1.mga5
+ Revision: 608023
- new version 2.40.0

* Mon Mar 17 2014 ovitters <ovitters> 2.39.92-1.mga5
+ Revision: 604545
- new version 2.39.92

* Mon Mar 03 2014 ovitters <ovitters> 2.39.91-1.mga5
+ Revision: 599030
- new version 2.39.91

* Tue Feb 18 2014 ovitters <ovitters> 2.39.90-1.mga5
+ Revision: 594093
- new version 2.39.90

* Wed Feb 12 2014 ovitters <ovitters> 2.39.4-2.mga5
+ Revision: 589729
- build with libelf support

* Tue Feb 04 2014 ovitters <ovitters> 2.39.4-1.mga5
+ Revision: 582465
- new version 2.39.4

* Mon Jan 13 2014 tmb <tmb> 2.38.2-4.mga4
+ Revision: 566453
- GDBusObjectManagerClient: keep the manager alive while firing
  signals (bgo#719402)
- kqueue: fix a potential deadlock (bgo{U+00A4}721074)
- gdesktopappinfo: Add missing annotations

* Tue Jan 07 2014 tv <tv> 2.38.2-3.mga4
+ Revision: 565322
- silent "No module named backtrace" warning when running gdb (bgo#613732)

* Mon Jan 06 2014 tv <tv> 2.38.2-2.mga4
+ Revision: 565176
- move the suggests on gvfs to gtk+3 (debloat, mga#8455)

* Tue Nov 12 2013 ovitters <ovitters> 2.38.2-1.mga4
+ Revision: 550851
- new version 2.38.2

* Tue Oct 22 2013 umeabot <umeabot> 2.38.1-2.mga4
+ Revision: 545463
- Mageia 4 Mass Rebuild

* Wed Oct 16 2013 ovitters <ovitters> 2.38.1-1.mga4
+ Revision: 501304
- new version 2.38.1

* Sun Sep 29 2013 wally <wally> 2.38.0-2.mga4
+ Revision: 489335
- add xfce4-terminal to supported terminals in GIO

* Mon Sep 23 2013 ovitters <ovitters> 2.38.0-1.mga4
+ Revision: 484561
- new version 2.38.0

* Tue Sep 17 2013 ovitters <ovitters> 2.37.93-1.mga4
+ Revision: 480922
- new version 2.37.93

* Mon Sep 16 2013 ovitters <ovitters> 2.37.92-1.mga4
+ Revision: 480366
- new version 2.37.92

* Mon Sep 02 2013 ovitters <ovitters> 2.37.7-1.mga4
+ Revision: 474426
- new version 2.37.7
+ tv <tv>
- do not package huge ChangeLog

* Tue Aug 20 2013 ovitters <ovitters> 2.37.6-1.mga4
+ Revision: 468304
- new version 2.37.6

* Tue Jul 30 2013 ovitters <ovitters> 2.37.5-1.mga4
+ Revision: 460711
- new version 2.37.5

* Tue Jul 09 2013 ovitters <ovitters> 2.37.4-1.mga4
+ Revision: 452252
- new version 2.37.4

* Mon Jun 24 2013 ovitters <ovitters> 2.37.3-1.mga4
+ Revision: 446291
- new version 2.37.3

* Mon Jun 17 2013 wally <wally> 2.37.2-1.mga4
+ Revision: 444152
- run autoreconf to fix build
+ ovitters <ovitters>
- new version 2.37.2

* Sat Jun 01 2013 ovitters <ovitters> 2.37.1-1.mga4
+ Revision: 433988
- kill autoreconf
+ tv <tv>
- new release

* Sun May 26 2013 blino <blino> 2.37.0-1.mga4
+ Revision: 428346
- run autoreconf to workaround automake mismatch
- 2.37.0

* Thu May 23 2013 fwang <fwang> 2.36.2-1.mga4
+ Revision: 425388
- update file list
+ tv <tv>
- adjust file list
- new release

* Sat Mar 23 2013 tmb <tmb> 2.34.3-4.mga3
+ Revision: 404698
- disable deprecated schema warnings as done on mga2 (P0)

* Sat Jan 12 2013 umeabot <umeabot> 2.34.3-3.mga3
+ Revision: 351820
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 01 2012 fwang <fwang> 2.34.3-2.mga3
+ Revision: 323596
- rebuild for new pcre

* Mon Nov 26 2012 ovitters <ovitters> 2.34.3-1.mga3
+ Revision: 322169
- new version 2.34.3

* Sun Nov 11 2012 fwang <fwang> 2.34.2-1.mga3
+ Revision: 316987
- new version 2.34.2

* Tue Oct 16 2012 ovitters <ovitters> 2.34.1-1.mga3
+ Revision: 306899
- new version 2.34.1

* Thu Oct 11 2012 ovitters <ovitters> 2.34.0-2.mga3
+ Revision: 304720
- like Fedora, also disable fam as glib already uses inotify. See http://lists.fedoraproject.org/pipermail/devel/2012-October/172438.htm

* Mon Sep 24 2012 ovitters <ovitters> 2.34.0-1.mga3
+ Revision: 296983
- new version 2.34.0

* Tue Sep 18 2012 fwang <fwang> 2.33.14-1.mga3
+ Revision: 295741
- drop upstream patch
- new version 2.33.14

* Mon Sep 17 2012 tv <tv> 2.33.12-2.mga3
+ Revision: 294821
- fix parsing file names (mga#452, gnome#683871)

* Mon Sep 03 2012 ovitters <ovitters> 2.33.12-1.mga3
+ Revision: 287750
- new version 2.33.12

* Tue Aug 21 2012 ovitters <ovitters> 2.33.10-1.mga3
+ Revision: 282762
- new version 2.33.10
+ tv <tv>
- try again with man pages

* Wed Aug 08 2012 tv <tv> 2.33.8-1.mga3
+ Revision: 279924
- looks like man pages & HTML doc are no more build
- looks like man pages are no more build
+ ovitters <ovitters>
- br docbook-style-xsl
- br docbook-xsl
- br docbook-dtds,libxml2-utils
- br xsltproc
- new version 2.33.8

* Mon Aug 06 2012 luigiwalser <luigiwalser> 2.33.6-2.mga3
+ Revision: 279046
- UsrMove fixes
- rebuild for libffi

* Tue Jul 17 2012 ovitters <ovitters> 2.33.6-1.mga3
+ Revision: 271991
- new version 2.33.6

* Mon Jul 16 2012 ovitters <ovitters> 2.33.4-1.mga3
+ Revision: 271274
- new version 2.33.4

* Mon Jun 25 2012 ovitters <ovitters> 2.33.3-1.mga3
+ Revision: 263740
- update file list
- new version 2.33.3

* Mon Jun 25 2012 ovitters <ovitters> 2.33.2-1.mga3
+ Revision: 263697
- new version 2.33.2

* Tue May 15 2012 ovitters <ovitters> 2.32.3-1.mga3
+ Revision: 235704
- new version 2.32.3
- new version 2.32.2

* Wed Apr 25 2012 ovitters <ovitters> 2.32.1-2.mga2
+ Revision: 233208
- silence deprecated paths message

* Sat Apr 14 2012 ovitters <ovitters> 2.32.1-1.mga2
+ Revision: 230746
- new version 2.32.1

* Sat Mar 24 2012 ovitters <ovitters> 2.32.0-1.mga2
+ Revision: 226066
- new version 2.32.0

* Mon Mar 19 2012 ovitters <ovitters> 2.31.22-1.mga2
+ Revision: 224514
- new version 2.31.22

* Mon Mar 05 2012 wally <wally> 2.31.20-1.mga2
+ Revision: 219097
- new version 2.31.20

* Fri Mar 02 2012 ovitters <ovitters> 2.31.18-1.mga2
+ Revision: 216868
- new version 2.31.18

* Sat Feb 18 2012 ovitters <ovitters> 2.31.16-2.mga2
+ Revision: 210476
- also compile glib schemas when override schema is installed (rpm filetrigger)

* Sun Feb 05 2012 fwang <fwang> 2.31.16-1.mga2
+ Revision: 204545
- new version 2.31.16

* Wed Feb 01 2012 fwang <fwang> 2.31.14-1.mga2
+ Revision: 203810
- update file list
- new version 2.31.14

* Thu Jan 26 2012 fwang <fwang> 2.31.12-5.mga2
+ Revision: 201900
- do not force to use lpthread

* Thu Jan 26 2012 fwang <fwang> 2.31.12-4.mga2
+ Revision: 201808
- foce lpthread for G_THREAD_LIBS

* Mon Jan 23 2012 tv <tv> 2.31.12-3.mga2
+ Revision: 200328
- drop suggests from main lib on common subpackage;
  since basesystem requires systemd that requires libglib,
  we had a whole dep tree that bring in gnome-keyring, gnupg2, dirmnr, colord,
  avahi, gamin & fuse in basesystem...
  let's unbloat this

* Mon Jan 23 2012 dmorgan <dmorgan> 2.31.12-2.mga2
+ Revision: 200180
- Own %%{_libdir}/glib-%%{api_version}

* Sat Jan 21 2012 ovitters <ovitters> 2.31.12-1.mga2
+ Revision: 198964
- new version

* Mon Jan 16 2012 ovitters <ovitters> 2.31.10-1.mga2
+ Revision: 197002
- package new files
- new version

* Tue Jan 10 2012 fwang <fwang> 2.31.8-1.mga2
+ Revision: 194438
- new version 2.31.8

* Mon Dec 19 2011 wally <wally> 2.31.6-1.mga2
+ Revision: 184580
- new version 2.31.6

* Tue Dec 13 2011 fwang <fwang> 2.31.4-1.mga2
+ Revision: 181238
- new version 2.31.4

* Tue Nov 22 2011 fwang <fwang> 2.31.2-1.mga2
+ Revision: 170724
- fix str fmt
- new version 2.31.2

* Tue Nov 08 2011 wally <wally> 2.31.0-2.mga2
+ Revision: 165597
- drop .la files

* Thu Oct 27 2011 wally <wally> 2.31.0-1.mga2
+ Revision: 158649
- new version 2.31.0

* Fri Oct 14 2011 wally <wally> 2.30.1-1.mga2
+ Revision: 155231
- new version 2.30.1

* Tue Sep 27 2011 fwang <fwang> 2.30.0-1.mga2
+ Revision: 149072
- new version 2.30.0

* Sun Sep 18 2011 fwang <fwang> 2.29.92-1.mga2
+ Revision: 145093
- new version 2.29.92

* Fri Sep 16 2011 fwang <fwang> 2.29.90-4.mga2
+ Revision: 144175
- requires /usr/bin/glib-compile-schemas when developing software

* Thu Sep 15 2011 tv <tv> 2.29.90-3.mga2
+ Revision: 143853
- s/requires/suggests/ common subpackage from library one in order to try
  harder not making installing udev ended in installing quite a lot of GNOME
  package (mga#609)
  previous attempt no more work since we now have new auto dependancies

* Wed Sep 14 2011 tv <tv> 2.29.90-2.mga2
+ Revision: 143467
- drop requires on libgio from glib2.0-common that was introduced in order to
  run gio-querymodules-* in  %%post, thus meaning installing udev ended in
  installing quite a lot of GNOME package (mga#609)
  however this is uneeded as those are now called from the gio package itself...

* Tue Sep 06 2011 wally <wally> 2.29.90-1.mga2
+ Revision: 139636
- new version 2.29.90

* Tue Aug 30 2011 fwang <fwang> 2.29.18-1.mga2
+ Revision: 136717
- update file list
- update file list
- new version 2.29.18
- new version 2.29.16
- new version 2.29.14

* Wed Jul 20 2011 fwang <fwang> 2.29.12-1.mga2
+ Revision: 127392
- new version 2.29.12

* Sat Jul 09 2011 cjw <cjw> 2.29.10-1.mga2
+ Revision: 120797
- 2.29.10

* Sun Jul 03 2011 dmorgan <dmorgan> 2.29.8-1.mga2
+ Revision: 117631
- Fix file list
- Fix buildrequires
- New version 2.29.8

* Thu Jun 09 2011 dmorgan <dmorgan> 2.28.8-1.mga2
+ Revision: 102504
- New version 2.28.8

* Fri May 06 2011 ahmad <ahmad> 2.28.6-3.mga1
+ Revision: 95271
- Revert the deleting of .la files, some packages don't build without it

* Thu May 05 2011 ahmad <ahmad> 2.28.6-2.mga1
+ Revision: 95191
- Split static libs in a separate sub-package
- Don't ship .la
- Use %%{__isa_bits} in %%{_bindir}/gio-querymodules-* (less lines in the spec)

* Thu Apr 14 2011 tv <tv> 2.28.6-1.mga1
+ Revision: 85363
- new release

* Thu Apr 07 2011 blino <blino> 2.28.5-2.mga1
+ Revision: 81627
- require libglib for libgio post  (needed for gio-querymodules)

* Sat Apr 02 2011 ahmad <ahmad> 2.28.5-1.mga1
+ Revision: 79751
- update to 2.28.5

* Sun Mar 27 2011 tv <tv> 2.28.4-4.mga1
+ Revision: 77972
- fix biarch install
+ ahmad <ahmad>
- fix typo in configure options, it's --with-runtime-libdir (Mandriva)

* Sat Mar 26 2011 pterjan <pterjan> 2.28.4-2.mga1
+ Revision: 77863
- Use filetrigger for gio module cache update

* Sat Mar 26 2011 ahmad <ahmad> 2.28.4-1.mga1
+ Revision: 77844
- update to 2.28.4
- move gio-querymodules.1* man page to the common subpackage

* Sat Feb 26 2011 pterjan <pterjan> 2.28.1-1.mga1
+ Revision: 60322
- Update to 2.28.1

* Sun Jan 09 2011 blino <blino> 2.26.1-4.mga1
+ Revision: 2213
- remove old requires/conflicts
- imported package glib2.0


* Thu Dec 16 2010 Funda Wang <fwang@mandriva.org> 2.26.1-3mdv2011.0
+ Revision: 622214
- rebuild

* Tue Nov 16 2010 Götz Waschk <waschk@mandriva.org> 2.26.1-2mdv2011.0
+ Revision: 597895
- move libs from /usr to / (bug #61661)
- new version
- revert to stable version 2.26.0

* Tue Oct 26 2010 Sandro Cazzaniga <kharec@mandriva.org> 2.27.1-1mdv2011.0
+ Revision: 589516
- update to 2.27.1

* Mon Sep 27 2010 Götz Waschk <waschk@mandriva.org> 2.26.0-1mdv2011.0
+ Revision: 581443
- update to new version 2.26.0

* Sun Sep 19 2010 Götz Waschk <waschk@mandriva.org> 2.25.17-1mdv2011.0
+ Revision: 579779
- new version
- drop patch 1

* Sat Sep 18 2010 Götz Waschk <waschk@mandriva.org> 2.25.16-1mdv2011.0
+ Revision: 579615
- new version
- fix build

* Tue Aug 31 2010 Götz Waschk <waschk@mandriva.org> 2.25.15-1mdv2011.0
+ Revision: 574573
- update to new version 2.25.15

* Mon Aug 16 2010 Götz Waschk <waschk@mandriva.org> 2.25.14-1mdv2011.0
+ Revision: 570635
- update to new version 2.25.14

* Sat Aug 07 2010 Götz Waschk <waschk@mandriva.org> 2.25.13-1mdv2011.0
+ Revision: 567286
- new version
- fix format strings

* Thu Jul 29 2010 Götz Waschk <waschk@mandriva.org> 2.25.12-1mdv2011.0
+ Revision: 563152
- update to new version 2.25.12

* Thu Jul 29 2010 Götz Waschk <waschk@mandriva.org> 2.25.11-1mdv2011.0
+ Revision: 563080
- new version
- update build deps
- add file trigger for gschemas compilation
- update file list
- move glib-gettextize data and man page to its package

* Mon May 03 2010 Götz Waschk <waschk@mandriva.org> 2.24.1-1mdv2010.1
+ Revision: 541701
- update to new version 2.24.1

* Fri Mar 26 2010 Götz Waschk <waschk@mandriva.org> 2.24.0-1mdv2010.1
+ Revision: 527860
- update to new version 2.24.0

* Mon Mar 22 2010 Götz Waschk <waschk@mandriva.org> 2.23.6-1mdv2010.1
+ Revision: 526305
- update to new version 2.23.6

* Mon Mar 08 2010 Götz Waschk <waschk@mandriva.org> 2.23.5-1mdv2010.1
+ Revision: 516411
- update to new version 2.23.5

* Fri Feb 26 2010 Götz Waschk <waschk@mandriva.org> 2.23.4-2mdv2010.1
+ Revision: 511506
- move gio-querymodules to the libgio package (Colin)

* Mon Feb 22 2010 Götz Waschk <waschk@mandriva.org> 2.23.4-1mdv2010.1
+ Revision: 509416
- update to new version 2.23.4

* Tue Feb 09 2010 Götz Waschk <waschk@mandriva.org> 2.23.3-1mdv2010.1
+ Revision: 503189
- update to new version 2.23.3

* Tue Feb 02 2010 Frederic Crozat <fcrozat@mandriva.com> 2.23.2-6mdv2010.1
+ Revision: 499568
- Add Requires(post) for gio modules list generation

* Tue Jan 26 2010 Götz Waschk <waschk@mandriva.org> 2.23.2-5mdv2010.1
+ Revision: 496844
- add giomodule.cache as ghost file
- rebuild with fam enabled

* Tue Jan 26 2010 Götz Waschk <waschk@mandriva.org> 2.23.2-3mdv2010.1
+ Revision: 496765
- add bootstrap flag
- filter deps to make the package installable

* Mon Jan 25 2010 Götz Waschk <waschk@mandriva.org> 2.23.2-1mdv2010.1
+ Revision: 496482
- new version
- handle gio-querymodules

* Mon Dec 21 2009 Götz Waschk <waschk@mandriva.org> 2.23.1-1mdv2010.1
+ Revision: 480906
- new version
- drop patch

* Fri Dec 18 2009 Götz Waschk <waschk@mandriva.org> 2.23.0-3mdv2010.1
+ Revision: 479883
- fix wrong includes (b.g.o #604893)

* Wed Dec 09 2009 Götz Waschk <waschk@mandriva.org> 2.23.0-2mdv2010.1
+ Revision: 475424
+ rebuild (emptylog)

* Wed Dec 09 2009 Götz Waschk <waschk@mandriva.org> 2.23.0-1mdv2010.1
+ Revision: 475421
- update build deps
- update to new version 2.23.0

* Tue Dec 01 2009 Götz Waschk <waschk@mandriva.org> 2.22.3-1mdv2010.1
+ Revision: 472337
- update to new version 2.22.3

* Mon Oct 12 2009 Nicolas Lécureuil <nlecureuil@mandriva.com> 2.22.2-2mdv2010.0
+ Revision: 456877
- Add Requires

* Wed Oct 07 2009 Götz Waschk <waschk@mandriva.org> 2.22.2-1mdv2010.0
+ Revision: 455624
- update to new version 2.22.2

* Wed Sep 30 2009 Götz Waschk <waschk@mandriva.org> 2.22.1-1mdv2010.0
+ Revision: 451174
- update to new version 2.22.1

* Wed Sep 23 2009 Götz Waschk <waschk@mandriva.org> 2.22.0-1mdv2010.0
+ Revision: 447654
- new version
- add gdb helpers to the devel package

* Sat Sep 05 2009 Götz Waschk <waschk@mandriva.org> 2.21.6-1mdv2010.0
+ Revision: 432061
- update to new version 2.21.6

* Mon Aug 24 2009 Götz Waschk <waschk@mandriva.org> 2.21.5-1mdv2010.0
+ Revision: 420515
- update to new version 2.21.5

* Sat Jul 18 2009 Götz Waschk <waschk@mandriva.org> 2.21.4-1mdv2010.0
+ Revision: 396990
- update to new version 2.21.4

* Mon Jul 06 2009 Götz Waschk <waschk@mandriva.org> 2.21.3-1mdv2010.0
+ Revision: 392694
- update to new version 2.21.3

* Mon Jun 15 2009 Götz Waschk <waschk@mandriva.org> 2.21.2-1mdv2010.0
+ Revision: 386106
- update to new version 2.21.2

* Fri May 29 2009 Götz Waschk <waschk@mandriva.org> 2.21.1-1mdv2010.0
+ Revision: 380868
- update to new version 2.21.1

* Mon May 11 2009 Götz Waschk <waschk@mandriva.org> 2.21.0-1mdv2010.0
+ Revision: 374171
- new version

* Fri Apr 10 2009 Frederic Crozat <fcrozat@mandriva.com> 2.20.1-1mdv2009.1
+ Revision: 365825
- Release 2.20.1
- Ensure selinux support is not build even if libselinux is installed

* Fri Mar 13 2009 Götz Waschk <waschk@mandriva.org> 2.20.0-1mdv2009.1
+ Revision: 354475
- new version
- drop patch 0

* Wed Mar 04 2009 Pascal Terjan <pterjan@mandriva.org> 2.19.10-2mdv2009.1
+ Revision: 348326
- Add upstream patch fixing draklive-install crash (#47762)

* Mon Mar 02 2009 Götz Waschk <waschk@mandriva.org> 2.19.10-1mdv2009.1
+ Revision: 346877
- update to new version 2.19.10

* Tue Feb 17 2009 Götz Waschk <waschk@mandriva.org> 2.19.8-1mdv2009.1
+ Revision: 342189
- update to new version 2.19.8

* Tue Feb 17 2009 Götz Waschk <waschk@mandriva.org> 2.19.7-1mdv2009.1
+ Revision: 341228
- update to new version 2.19.7

* Mon Feb 02 2009 Götz Waschk <waschk@mandriva.org> 2.19.6-1mdv2009.1
+ Revision: 336676
- update to new version 2.19.6

* Mon Jan 19 2009 Götz Waschk <waschk@mandriva.org> 2.19.5-1mdv2009.1
+ Revision: 331129
- update to new version 2.19.5

* Tue Jan 06 2009 Götz Waschk <waschk@mandriva.org> 2.19.4-1mdv2009.1
+ Revision: 325348
- new version

* Thu Dec 18 2008 Götz Waschk <waschk@mandriva.org> 2.19.3-1mdv2009.1
+ Revision: 315786
- update to new version 2.19.3

* Tue Dec 02 2008 Götz Waschk <waschk@mandriva.org> 2.19.2-1mdv2009.1
+ Revision: 309033
- update to new version 2.19.2

* Tue Dec 02 2008 Götz Waschk <waschk@mandriva.org> 2.19.1-1mdv2009.1
+ Revision: 308988
- update to new version 2.19.1

* Mon Nov 24 2008 Götz Waschk <waschk@mandriva.org> 2.18.3-1mdv2009.1
+ Revision: 306204
- update to new version 2.18.3

* Thu Oct 16 2008 Götz Waschk <waschk@mandriva.org> 2.18.2-1mdv2009.1
+ Revision: 294523
- new version

* Thu Sep 18 2008 Götz Waschk <waschk@mandriva.org> 2.18.1-1mdv2009.0
+ Revision: 285595
- new version

* Wed Sep 03 2008 Götz Waschk <waschk@mandriva.org> 2.18.0-1mdv2009.0
+ Revision: 279563
- new version

* Mon Aug 18 2008 Frederic Crozat <fcrozat@mandriva.com> 2.17.7-1mdv2009.0
+ Revision: 273278
- Release 2.17.7

* Mon Aug 04 2008 Götz Waschk <waschk@mandriva.org> 2.17.6-1mdv2009.0
+ Revision: 263481
- new version

* Tue Jul 22 2008 Götz Waschk <waschk@mandriva.org> 2.17.4-1mdv2009.0
+ Revision: 240014
- new version
- drop patch
- update license

* Fri Jul 04 2008 Götz Waschk <waschk@mandriva.org> 2.17.3-2mdv2009.0
+ Revision: 231604
- crash fix

* Thu Jul 03 2008 Götz Waschk <waschk@mandriva.org> 2.17.3-1mdv2009.0
+ Revision: 230878
- new version

* Fri Jun 13 2008 Götz Waschk <waschk@mandriva.org> 2.17.2-1mdv2009.0
+ Revision: 218734
- new version

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Wed Apr 09 2008 Götz Waschk <waschk@mandriva.org> 2.16.3-1mdv2009.0
+ Revision: 192488
- new version

* Tue Apr 01 2008 Frederic Crozat <fcrozat@mandriva.com> 2.16.2-1mdv2008.1
+ Revision: 191354
- Release 2.16.2
- Remove patch0, merged upstream

* Thu Mar 27 2008 Frederic Crozat <fcrozat@mandriva.com> 2.16.1-3mdv2008.1
+ Revision: 190728
- Update patch0 with more SVN fixes

* Mon Mar 17 2008 Frederic Crozat <fcrozat@mandriva.com> 2.16.1-2mdv2008.1
+ Revision: 188329
- Patch0: SVN fixes for gio

* Tue Mar 11 2008 Götz Waschk <waschk@mandriva.org> 2.16.1-1mdv2008.1
+ Revision: 184860
- new version

* Mon Mar 10 2008 Götz Waschk <waschk@mandriva.org> 2.16.0-1mdv2008.1
+ Revision: 183715
- new version

* Mon Mar 03 2008 Götz Waschk <waschk@mandriva.org> 2.15.6-2mdv2008.1
+ Revision: 178232
- add missing dep on libgio to the devel package

* Mon Feb 25 2008 Götz Waschk <waschk@mandriva.org> 2.15.6-1mdv2008.1
+ Revision: 175044
- new version

* Mon Feb 25 2008 Pixel <pixel@mandriva.com> 2.15.5-2mdv2008.1
+ Revision: 174900
- create subpackage libgio2.0_0 which suggests libgvfs0 to break require/suggest
  link consolekit->glib->gvfs->hal

* Tue Feb 12 2008 Götz Waschk <waschk@mandriva.org> 2.15.5-1mdv2008.1
+ Revision: 165677
- new version
- drop patch 0

* Thu Feb 07 2008 Götz Waschk <waschk@mandriva.org> 2.15.4-3mdv2008.1
+ Revision: 163376
- build with system pcre

* Wed Feb 06 2008 Frederic Crozat <fcrozat@mandriva.com> 2.15.4-2mdv2008.1
+ Revision: 163034
- Patch0 (SVN): fix text sniffing (Mdv bug #37506)

* Tue Jan 29 2008 Götz Waschk <waschk@mandriva.org> 2.15.4-1mdv2008.1
+ Revision: 159640
- new version
- drop patch

* Tue Jan 22 2008 Götz Waschk <waschk@mandriva.org> 2.15.3-1mdv2008.1
+ Revision: 156114
- new version

* Wed Jan 16 2008 Guillaume Rousse <guillomovitch@mandriva.org> 2.15.2-2mdv2008.1
+ Revision: 153773
- no executable bit on profile.d scriptlets
  order prefix for profile.d scriptlets

* Mon Jan 14 2008 Götz Waschk <waschk@mandriva.org> 2.15.2-1mdv2008.1
+ Revision: 151584
- new version

* Wed Jan 09 2008 Frederic Crozat <fcrozat@mandriva.com> 2.15.1-3mdv2008.1
+ Revision: 147222
- Patch1: consider rpc_pipefs as system fs (GNOME bug 508309)

* Tue Jan 08 2008 Frederic Crozat <fcrozat@mandriva.com> 2.15.1-2mdv2008.1
+ Revision: 146589
- Suggest gvfs when installing glib

* Mon Jan 07 2008 Götz Waschk <waschk@mandriva.org> 2.15.1-1mdv2008.1
+ Revision: 146356
- new version
- drop patches 1,2

* Thu Jan 03 2008 Oden Eriksson <oeriksson@mandriva.com> 2.15.0-3mdv2008.1
+ Revision: 141712
- added P2 to fix anal comment format in gtestutils.h

* Fri Dec 28 2007 Frederic Crozat <fcrozat@mandriva.com> 2.15.0-2mdv2008.1
+ Revision: 138769
- Patch1 (SVN): fix environment in g_spawn_async (GNOME bug #504829)

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Götz Waschk <waschk@mandriva.org>
    - new devel name

* Fri Dec 21 2007 Götz Waschk <waschk@mandriva.org> 2.15.0-1mdv2008.1
+ Revision: 136175
- new version
- update buildrequires
- update file list

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Sat Nov 24 2007 Götz Waschk <waschk@mandriva.org> 2.14.4-1mdv2008.1
+ Revision: 111790
- new version

* Wed Nov 07 2007 Götz Waschk <waschk@mandriva.org> 2.14.3-1mdv2008.1
+ Revision: 106684
- new version

* Tue Oct 16 2007 Götz Waschk <waschk@mandriva.org> 2.14.2-1mdv2008.1
+ Revision: 98888
- new version
- drop patch 1

* Fri Sep 28 2007 Frederic Crozat <fcrozat@mandriva.com> 2.14.1-2mdv2008.0
+ Revision: 93673
- Patch1 (SVN): fix crash on hook finalization (GNOME bug #476849)

* Mon Sep 17 2007 Götz Waschk <waschk@mandriva.org> 2.14.1-1mdv2008.0
+ Revision: 88888
- new version

* Wed Aug 22 2007 Adam Williamson <awilliamson@mandriva.org> 2.14.0-2mdv2008.0
+ Revision: 68757
- patch0 from PLD Linux: fix upstream regression breaking noarch builds (GNOME bug #385132)

* Sat Aug 04 2007 Götz Waschk <waschk@mandriva.org> 2.14.0-1mdv2008.0
+ Revision: 58861
- new version
- drop patch
- disable checks

* Tue Jul 24 2007 Christiaan Welvaart <spturtle@mandriva.org> 2.13.7-2mdv2008.0
+ Revision: 55081
- drop patch0, fixed upstream
- patch0: fix new testsuite failure on ppc

* Fri Jul 13 2007 Frederic Crozat <fcrozat@mandriva.com> 2.13.7-1mdv2008.0
+ Revision: 51774
- Release 2.13.7 (aka no more g_thread_init warning release)

* Fri Jun 29 2007 Götz Waschk <waschk@mandriva.org> 2.13.6-1mdv2008.0
+ Revision: 45874
- new version

* Mon Jun 18 2007 Götz Waschk <waschk@mandriva.org> 2.13.5-1mdv2008.0
+ Revision: 41045
- new version

* Thu Jun 07 2007 Anssi Hannula <anssi@mandriva.org> 2.13.4-2mdv2008.0
+ Revision: 36161
- rebuild with correct optflags

  + Götz Waschk <waschk@mandriva.org>
    - new version

* Wed May 02 2007 Götz Waschk <waschk@mandriva.org> 2.12.12-1mdv2008.0
+ Revision: 20394
- new version


* Fri Mar 09 2007 Götz Waschk <waschk@mandriva.org> 2.12.11-1mdv2007.1
+ Revision: 138716
- new version
- drop patch 1

  + Frederic Crozat <fcrozat@mandriva.com>
    - Patch1 : disable forgotten debug

* Thu Mar 08 2007 Frederic Crozat <fcrozat@mandriva.com> 2.12.10-1mdv2007.1
+ Revision: 137648
- Release 2.12.10

* Sun Feb 18 2007 Götz Waschk <waschk@mandriva.org> 2.12.9-3mdv2007.1
+ Revision: 122247
- rebuild to fix pkgconfig deps

* Sat Feb 17 2007 Götz Waschk <waschk@mandriva.org> 2.12.9-2mdv2007.1
+ Revision: 122121
- rebuild for pkgconfig provides

* Wed Jan 17 2007 Götz Waschk <waschk@mandriva.org> 2.12.9-1mdv2007.1
+ Revision: 109724
- new version
- disable gtk-doc

* Mon Jan 15 2007 Götz Waschk <waschk@mandriva.org> 2.12.8-1mdv2007.1
+ Revision: 108997
- new version
- drop patch

* Fri Jan 05 2007 Götz Waschk <waschk@mandriva.org> 2.12.7-2mdv2007.1
+ Revision: 104389
- bump release
- fix build
- new version

* Wed Dec 20 2006 Götz Waschk <waschk@mandriva.org> 2.12.6-1mdv2007.1
+ Revision: 100530
- new version

* Tue Dec 19 2006 Götz Waschk <waschk@mandriva.org> 2.12.5-1mdv2007.1
+ Revision: 99115
- new version

* Tue Oct 17 2006 Christiaan Welvaart <cjw@daneel.dyndns.org> 2.12.4-4mdv2007.1
+ Revision: 65622
- patch0: fix for plt check script on ppc

* Fri Oct 13 2006 Götz Waschk <waschk@mandriva.org> 2.12.4-3mdv2007.1
+ Revision: 63823
- rebuild
- rebuild
- Import glib2.0

* Thu Oct 05 2006 Götz Waschk <waschk@mandriva.org> 2.12.4-1mdv2007.0
- New version 2.12.4

* Sat Sep 09 2006 Frederic Crozat <fcrozat@mandriva.com> 2.12.3-3mdv2007.0
- Update source 2 and 3 to prevent invalid dep on tcsh

* Sat Sep 09 2006 Frederic Crozat <fcrozat@mandriva.com> 2.12.3-2mdv2007.0
- Create common package for non-arch data used by lib package
- Put back exec permissions on profile scripts

* Thu Aug 31 2006 Götz Waschk <waschk@mandriva.org> 2.12.3-1mdv2007.0
- New release 2.12.3

* Thu Aug 17 2006 Götz Waschk <waschk@mandriva.org> 2.12.2-1mdv2007.0
- New release 2.12.2

* Mon Jul 24 2006 Götz Waschk <waschk@mandriva.org> 2.12.1-1mdv2007.0
- New release 2.12.1

* Tue Jul 04 2006 Götz Waschk <waschk@mandriva.org> 2.12.0-1mdv2007.0
- fix profile.d permissions
- New release 2.12.0

* Wed Jun 21 2006 Götz Waschk <waschk@mandriva.org> 2.11.4-1mdv2007.0
- fix rpmlint warning about missing shell bang
- New release 2.11.4

* Wed Jun 14 2006 Götz Waschk <waschk@mandriva.org> 2.11.3-1mdv2007.0
- New release 2.11.3

* Wed Jun 07 2006 Götz Waschk <waschk@mandriva.org> 2.11.2-1
- New release 2.11.2

* Thu Jun 01 2006 Frederic Crozat <fcrozat@mandriva.com> 2.11.1-1mdv2007.0
- Release 2.11.1

* Mon May 29 2006 Götz Waschk <waschk@mandriva.org> 2.10.3-1mdv2007.0
- drop patch
- New release 2.10.3

* Wed Apr 12 2006 Götz Waschk <waschk@mandriva.org> 2.10.2-2mdk
- fix buildrequires

* Tue Apr 11 2006 Frederic Crozat <fcrozat@mandriva.com> 2.10.2-1mdk
- Release 2.10.2
- Patch0 (CVS): fix thread test

* Fri Jan 20 2006 Götz Waschk <waschk@mandriva.org> 2.8.6-1mdk
- drop merged patch
- New release 2.8.6

* Wed Jan 18 2006 Christiaan Welvaart <cjw@daneel.dyndns.org> 2.8.5-2mdk
- patch1: fix convert-test for ppc

* Tue Jan 03 2006 Götz Waschk <waschk@mandriva.org> 2.8.5-1mdk
- New release 2.8.5
- use mkrel

* Wed Nov 16 2005 Götz Waschk <waschk@mandriva.org> 2.8.4-1mdk
- New release 2.8.4

* Wed Oct 12 2005 Frederic Crozat <fcrozat@mandriva.com> 2.8.3-2mdk
- Rebuild to get debug package

* Wed Oct 05 2005 Frederic Crozat <fcrozat@mandriva.com> 2.8.3-1mdk
- Release 2.8.3

* Wed Aug 24 2005 Frederic Crozat <fcrozat@mandriva.com> 2.8.1-1mdk 
- New release 2.8.1
- Remove patch1 (merged upstream)

* Fri Aug 19 2005 Christiaan Welvaart <cjw@daneel.dyndns.org> 2.8.0-2mdk
- patch1: have abicheck.sh accept symbols in small data area etc.

* Wed Aug 17 2005 Frederic Crozat <fcrozat@mandriva.com> 2.8.0-1mdk 
- Release 2.8.0

* Tue Aug 02 2005 Götz Waschk <waschk@mandriva.org> 2.6.6-1mdk
- rpmbuildupdate fix
- New release 2.6.6

* Sun Jun 12 2005 Götz Waschk <waschk@mandriva.org> 2.6.5-1mdk
- New release 2.6.5

* Sat Apr 16 2005 Frederic Crozat <fcrozat@mandriva.com> 2.6.4-1mdk 
- Release 2.6.4

* Mon Feb 28 2005 Frederic Crozat <fcrozat@mandrakesoft.com> 2.6.3-1mdk 
- Release 2.6.3
- Remove patch1 (not needed anymore)

* Fri Feb 18 2005 Frederic Crozat <fcrozat@mandrakesoft.com> 2.6.2-3mdk 
- Fix bad encoding in source1/2 (next time, I'll check doc myself..)

* Fri Feb 18 2005 Frederic Crozat <fcrozat@mandrakesoft.com> 2.6.2-2mdk 
- Update source1/2 to use G_FILENAME_ENCODING (Mdk bug #13738)

* Fri Feb 04 2005 Frederic Crozat <fcrozat@mandrakesoft.com> 2.6.2-1mdk
- New release 2.6.2

* Sun Jan 09 2005 Götz Waschk <waschk@linux-mandrake.com> 2.6.1-1mdk
- new version

* Sat Dec 18 2004 Christiaan Welvaart <cjw@daneel.dyndns.org> 2.6.0-2mdk
- Patch1: fix abicheck in test suite for ppc

* Thu Dec 16 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.6.0-1mdk
- New release 2.6.0

* Fri Dec 03 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.4.8-1mdk 
- Release 2.4.8

* Tue Oct 19 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.4.7-1mdk
- New release 2.4.7

* Tue Aug 17 2004 Götz Waschk <waschk@linux-mandrake.com> 2.4.6-1mdk
- new version

* Tue Aug 03 2004 Götz Waschk <waschk@linux-mandrake.com> 2.4.5-1mdk
- new version

* Sat Jul 10 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.4.4-1mdk
- New release 2.4.4

* Sat Jun 05 2004 Götz Waschk <waschk@linux-mandrake.com> 2.4.2-1mdk
- reenable libtoolize
- New release 2.4.2

* Sat May 01 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.4.1-1mdk
- Release 2.4.1

* Thu Apr 01 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.4.0-1mdk
- Release 2.4.0

